@@ -3,7 +3,7 @@
 /*
  *  Quick Lounge Applet
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2004 The Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -106,12 +106,14 @@ help_verb_cb (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	gnome_help_display_desktop (NULL, 
-				    "quick-lounge-applet", 
-				    NULL,
-				    NULL, 
-				    &error);
-	
+	gnome_help_display_desktop_on_screen (
+	      NULL,
+	      "quick-lounge", 
+	      "quick-lounge", 
+	      NULL, 
+	      gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)),
+	      &error);
+
 	if (error) {       
 		_gtk_error_dialog_run (NULL, 
 				       ERROR_FORMAT, 
@@ -130,40 +132,34 @@ about_verb_cb (BonoboUIComponent *uic,
 	GdkPixbuf  *pixbuf = NULL;
         char       *file;
 	const char *authors[] = {
-		"Paolo Bacchilega <paolo.bacch@tin.it>",
+		"Paolo Bacchilega <paolo.bacchilega@libero.it>",
 		NULL
 	};
 	const char *documenters [] = {
+		"Sun GNOME Documentation Team",
 		NULL
 	};
 	const char *translator_credits = _("translator_credits");
 	
-	if (quick_lounge->about_dialog != NULL) {
-		gtk_window_present (GTK_WINDOW (quick_lounge->about_dialog));
-                return;
-	}
-	
 	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "quick-lounge-applet.png", TRUE, NULL);
-        pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-        g_free(file);
+	if (file != NULL) {
+		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+		g_free(file);
+	}
 
-	quick_lounge->about_dialog = gnome_about_new (_("Quick Lounge"), 
-						      VERSION,
-						      "Copyright \xc2\xa9 2002-2003 Free Software Foundation, Inc.",
-						      _("Organize your favorite applications on the Panel"),
-						      authors,
-						      documenters,
-						      strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-						      pixbuf);
+	gtk_show_about_dialog (NULL,
+			       "name", _("Launchers List"),
+			       "version", VERSION,
+			       "copyright", "Copyright \xc2\xa9 2002-2004 Free Software Foundation, Inc.",
+			       "comments", _("Organize your favorite applications on the Panel"),
+			       "authors", authors,
+			       "documenters", documenters,
+			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			       "logo", pixbuf,
+			       NULL);
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (quick_lounge->about_dialog), GNOME_ICONDIR "quick-lounge-applet.png");
-
-	g_signal_connect (G_OBJECT (quick_lounge->about_dialog), 
-			  "destroy",
-			  G_CALLBACK (gtk_widget_destroyed), 
-			  &quick_lounge->about_dialog);
-
-	gtk_widget_show_all (quick_lounge->about_dialog);
+	if (pixbuf)
+		g_object_unref (pixbuf);
 }
 
 
@@ -194,7 +190,7 @@ remove_directory (const char *uri)
 	file_info = gnome_vfs_file_info_new ();
 	while (gnome_vfs_directory_read_next (h, file_info) == GNOME_VFS_OK) {
 		char *file_uri;
-		file_uri = g_strconcat (uri, "/", file_info->name, NULL);
+		file_uri = g_build_filename (uri, file_info->name, NULL);
 		gnome_vfs_unlink (file_uri);
 		g_free (file_uri);
 	}
@@ -221,8 +217,9 @@ applet_destroy (GtkWidget    *applet,
 {
 	/* free memory */
 
-	if (quick_lounge->about_dialog != NULL)
-                gtk_widget_destroy (quick_lounge->about_dialog);
+	if (quick_lounge->prop_dialog != NULL)
+                gtk_widget_destroy (quick_lounge->prop_dialog);
+
 	g_free (quick_lounge->location);
 
 	if (quick_lounge->ditem_hash != NULL) {
@@ -255,10 +252,10 @@ applet_change_size (PanelApplet   *applet,
                     int            size,
                     QuickLounge   *quick_lounge)
 {
-	if (quick_lounge->size == size)
-                return;
-	quick_lounge->size = size;
-	quick_box_set_size (quick_lounge->quick_box, size);
+	if (quick_lounge->size != size) {
+		quick_lounge->size = size;
+		quick_box_set_size (quick_lounge->quick_box, size);
+	}
 }
 
 
@@ -266,21 +263,38 @@ static void
 applet_change_background (PanelApplet               *applet,
                           PanelAppletBackgroundType  type,
                           GdkColor                  *color,
-                          const gchar               *pixmap,
+                          GdkPixmap                 *pixmap,
                           QuickLounge               *quick_lounge)
 {
-	GtkWidget *widget = GTK_WIDGET (applet);
-
-	if (type == PANEL_NO_BACKGROUND) {
-		GtkRcStyle *rc_style = gtk_rc_style_new ();
-		gtk_widget_modify_style (widget, rc_style);
-		gtk_rc_style_unref (rc_style);
-
-	} else if (type == PANEL_COLOR_BACKGROUND) 
-		gtk_widget_modify_bg (widget, GTK_STATE_NORMAL, color);
-
-	else if ((type == PANEL_PIXMAP_BACKGROUND) && (pixmap != NULL)) {
-		/* FIXME */
+	/* taken from the Trash Applet */
+	GtkRcStyle *rc_style;
+	GtkStyle *style;
+	
+	/* reset style */
+	gtk_widget_set_style (GTK_WIDGET (applet), NULL);
+	rc_style = gtk_rc_style_new ();
+	gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
+	gtk_rc_style_unref (rc_style);	
+	
+	switch (type) {
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (applet),
+				      GTK_STATE_NORMAL, 
+				      color);
+		break;
+		
+	case PANEL_PIXMAP_BACKGROUND:
+		style = gtk_style_copy (GTK_WIDGET (applet)->style);
+		if (style->bg_pixmap[GTK_STATE_NORMAL] != NULL)
+			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+		gtk_widget_set_style (GTK_WIDGET (applet), style);
+		g_object_unref (style);
+		break;
+		
+	case PANEL_NO_BACKGROUND:
+	default:
+		break;
 	}
 }
 
@@ -303,6 +317,32 @@ applet_size_request (GtkWidget      *widget,
 }
 
 
+static void
+applet_size_allocate (GtkWidget      *widget,
+		      GtkAllocation  *allocation,
+		      QuickLounge    *quick_lounge)
+{
+	int size;
+
+	switch (quick_lounge->orientation) {
+	case PANEL_APPLET_ORIENT_LEFT:
+	case PANEL_APPLET_ORIENT_RIGHT:
+		size = allocation->width;
+		break;
+	case PANEL_APPLET_ORIENT_UP:
+	case PANEL_APPLET_ORIENT_DOWN:
+	default:
+		size = allocation->height;
+		break;
+	}
+
+	if (quick_lounge->size != size) {
+		quick_lounge->size = size;
+		quick_box_set_size (quick_lounge->quick_box, size);
+	}
+}
+
+
 /* -- Button Context Menu -- */
 
 
@@ -468,9 +508,6 @@ ditem_properties_close (GtkWidget *dialog,
 }
 
 
-/* ---- 8< ---- 8< ---- */
-
-
 void
 quick_lounge_util__item_properties (QuickLounge *quick_lounge,
 				    GtkWidget   *button)
@@ -578,160 +615,6 @@ item_move_cb (GtkWidget *button)
 }
 
 
-/* -- show help on app -- */
-
-/* -----8<----- cut & paste from the gnome-panel -----8<----- */
-
-GQuark
-panel_help_error_quark (void)
-{
-        static GQuark q = 0;
-        if (q == 0)
-                q = g_quark_from_static_string ("panel-help-error-quark");
-
-        return q;
-}
-
-typedef enum {
-        PANEL_HELP_ERROR_NO_DOCPATH /* No docpath sent */,
-        PANEL_HELP_ERROR_NOT_FOUND /* Document not found */
-} PanelHelpError;
-
-#define PANEL_HELP_ERROR panel_help_error_quark ()
-
-static gboolean
-panel_show_gnome_help (const char *docpath, GError **error)
-{
-        char *app, *p, *path;
-        gboolean retval;
-
-        app = g_strdup (docpath);
-
-        p = strchr (app, '/');
-
-        if (p == NULL) {
-                g_free (app);
-                g_set_error (error,
-                             PANEL_HELP_ERROR,
-                             PANEL_HELP_ERROR_NOT_FOUND,
-                             /* XXX: Not really a correct error,
-                              * but just somewhat correct */
-                             _("Help document not found"));
-                return FALSE;
-        }
-
-        path = p+1;
-        *p = '\0';
-
-        retval = TRUE;
-
-        if ( ! gnome_help_display_desktop (NULL /* program */,
-                                           app /* doc_id */,
-                                           path /* file_name */,
-                                           NULL /* link_id */,
-                                           error)) {
-                retval = gnome_help_display_with_doc_id (NULL /* program */,
-                                                         app /* doc_id */,
-                                                         path /* file_name */,
-                                                         NULL /* link_id */,
-                                                         error);
-        }
-
-        g_free (app);
-
-        return retval;
-}
-
-
-static gboolean
-panel_show_kde_help (const char *docpath, GError **error)
-{
-        const GList *li;
-
-        if ( ! g_file_test (KDE_DOCDIR, G_FILE_TEST_EXISTS)) {
-                g_set_error (error,
-                             PANEL_HELP_ERROR,
-                             PANEL_HELP_ERROR_NOT_FOUND,
-                             _("Help document not found"));
-                return FALSE;
-        }
-
-        for (li = gnome_i18n_get_language_list ("LC_MESSAGES");
-             li != NULL;
-             li = li->next) {
-                char *fullpath = g_strdup_printf ("%s/HTML/%s/%s",
-                                                  KDE_DOCDIR,
-                                                  (char *)li->data,
-                                                  docpath);
-                if (g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
-                        gboolean retval;
-                        char *uri = g_strconcat ("ghelp:", fullpath, NULL);
-                        g_free (fullpath);
-                        retval = gnome_help_display_uri (uri, error);
-                        g_free (uri);
-                        return retval;
-                }
-                g_free (fullpath);
-        }
-	
-	g_set_error (error,
-                     PANEL_HELP_ERROR,
-                     PANEL_HELP_ERROR_NOT_FOUND,
-                     _("Help document not found"));
-
-        return FALSE;
-}
-
-
-/* is url showable by gnome_url_show */
-gboolean
-panel_is_url (const char *url)
-{
-        if (strncmp (url, "http://", strlen ("http://")) == 0 ||
-            strncmp (url, "https://", strlen ("https://")) == 0 ||
-            strncmp (url, "gopher://", strlen ("gopher://")) == 0 ||
-            strncmp (url, "ftp://", strlen ("ftp://")) == 0 ||
-            strncmp (url, "file:", strlen ("file:")) == 0 ||
-            strncmp (url, "ghelp:", strlen ("ghelp:")) == 0 ||
-            strncmp (url, "help:", strlen ("help:")) == 0 ||
-            strncmp (url, "man:", strlen ("man:")) == 0 ||
-            strncmp (url, "info:", strlen ("info:")) == 0)
-                return TRUE;
-        else
-                return FALSE;
-}
-
-
-/* -----8<----- cut & paste from the gnome-panel -----8<----- */
-
-
-static void
-item_help_on_app_cb (GtkWidget *button)
-{
-	GnomeDesktopItem *ditem;
-	const char       *docpath;
-	GError           *err = NULL;
-
-	ditem = g_object_get_data (G_OBJECT (button), "ditem");
-	docpath = gnome_desktop_item_get_localestring (ditem, "X-GNOME-DocPath");
-
-	if (panel_is_url (docpath))
-                gnome_help_display_uri (docpath, &err);
-	else if (! panel_show_gnome_help (docpath, &err)) {
-		g_clear_error (&err);
-		panel_show_kde_help (docpath, &err);
-	}
-	
-        if (err != NULL) {
-		_gtk_error_dialog_run (NULL,
-				       ERROR_FORMAT,
-				       _("Could not display help"),
-				       err->message);
-                g_error_free (err);
-        }
-}
-
-
 static int
 get_child_position (QuickBox  *quick_box,
 		    GtkWidget *widget)
@@ -765,18 +648,6 @@ quick_lounge_util__get_unique_uri (QuickLounge *quick_lounge)
 }
 
 
-void
-quick_lounge_set_textdomain ()
-{
-	static gboolean domain_setted = FALSE;
-
-	if (!domain_setted) {
-		/* textdomain (GETTEXT_PACKAGE); FIXME */
-		domain_setted = TRUE;
-	}
-}
-
-
 /* -- */
 
 
@@ -800,12 +671,18 @@ new_launcher_dialog_response_cb (GtkWidget *dialog,
 		
 	} else if (response == GTK_RESPONSE_OK) { 
 		GnomeDesktopItem *ditem;
-		char             *uri;
+		char             *uri, *path;
+		GnomeVFSURI      *vfs_uri;
 
 		uri = quick_lounge_util__get_unique_uri (quick_lounge);
 
+		vfs_uri = gnome_vfs_uri_new (uri);
+		path = gnome_vfs_uri_to_string (vfs_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
+		gnome_vfs_uri_unref (vfs_uri);
+
 		ditem = gnome_ditem_edit_get_ditem (dedit);
-		gnome_desktop_item_set_location_file (ditem, uri + strlen ("file://"));
+		gnome_desktop_item_set_location_file (ditem, path);
+		g_free (path);
 
 		if (! gnome_desktop_item_save (ditem, NULL, TRUE, NULL)) {
 			_gtk_error_dialog_run (NULL, 
@@ -945,13 +822,7 @@ populate_context_menu (GtkWidget *popup_menu,
 		       GtkWidget *button,
 		       gpointer   data)
 {
-	GtkWidget        *item;
-	GnomeDesktopItem *ditem;
-	const char       *docpath;
-
-	quick_lounge_set_textdomain ();
-
-	/**/
+	GtkWidget *item;
 
 	if (! QUICK_IS_SEPARATOR (button)) {
 		item = gtk_image_menu_item_new_with_mnemonic (_("_Properties"));
@@ -963,59 +834,19 @@ populate_context_menu (GtkWidget *popup_menu,
 				  "activate",
 				  G_CALLBACK (activate_item_cb), 
 				  button);
-	}
 
-	/**/
-
-	item = gtk_image_menu_item_new_with_mnemonic (_("_Help"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_HELP, GTK_ICON_SIZE_MENU));
-	gtk_widget_show_all (item);
-
-	/**/
-
-	ditem = g_object_get_data (G_OBJECT (button), "ditem");
-	docpath = gnome_desktop_item_get_localestring (ditem, "X-GNOME-DocPath");
-	if (docpath != NULL) {
-		const char *app_name;
-		char       *label;
-
-		app_name = gnome_desktop_item_get_localestring (ditem, "Name");
-		label = g_strdup_printf (_("Help on %s Application"), app_name);
-		item = gtk_image_menu_item_new_with_mnemonic (label);
-		g_free (label);
-
-		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_HELP, GTK_ICON_SIZE_MENU));
-		gtk_widget_show_all (item);
+		/**/
 		
-		g_signal_connect_swapped (G_OBJECT (item), 
-					  "activate",
-					  G_CALLBACK (item_help_on_app_cb), 
-					  button);
+		item = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+		gtk_widget_show_all (item);
 	}
 
 	/**/
 
-	item = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_widget_show_all (item);
-
-	/**/
-
-	item = gtk_image_menu_item_new_with_mnemonic (_("Add _Launcher"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
-	gtk_widget_show_all (item);
-
-	g_signal_connect_swapped (G_OBJECT (item), 
-				  "activate",
-				  G_CALLBACK (add_launcher_cb), 
-				  button);
-
-	/**/
-
-	item = gtk_image_menu_item_new_with_mnemonic (_("Add From _Menu"));
+	item = gtk_image_menu_item_new_with_mnemonic (_("Add _Existing Launcher"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
 	gtk_widget_show_all (item);
 
 	g_signal_connect_swapped (G_OBJECT (item), 
@@ -1027,6 +858,7 @@ populate_context_menu (GtkWidget *popup_menu,
 
 	item = gtk_image_menu_item_new_with_mnemonic (_("Add _Space"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
 	gtk_widget_show_all (item);
 
 	g_signal_connect_swapped (G_OBJECT (item), 
@@ -1036,6 +868,18 @@ populate_context_menu (GtkWidget *popup_menu,
 
 	/**/
 
+	item = gtk_image_menu_item_new_with_mnemonic (_("Add _New Launcher"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU));
+	gtk_widget_show_all (item);
+
+	g_signal_connect_swapped (G_OBJECT (item), 
+				  "activate",
+				  G_CALLBACK (add_launcher_cb), 
+				  button);
+
+	/**/
+
 	item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 	gtk_widget_show_all (item);
@@ -1111,6 +955,8 @@ drag_data_received  (GtkWidget          *widget,
                 return;
         }
 
+	gtk_drag_finish (context, TRUE, FALSE, time);
+
 	pos = quick_box_get_pointer_position (quick_box, x, y);
 
 	list = get_file_list_from_url_list ((char *) data->data);
@@ -1123,10 +969,9 @@ drag_data_received  (GtkWidget          *widget,
 		if (! is_desktop_file (src_uri))
 			continue;
 
-		uri = g_strconcat (quick_lounge->location,
-				   "/",
-				   file_name_from_path (src_uri),
-				   NULL);
+		uri = g_build_filename (quick_lounge->location,
+					file_name_from_path (src_uri),
+					NULL);
 
 		if (strcmp (src_uri, uri) == 0) {
 			button = get_button_from_uri (quick_box, uri);
@@ -1155,7 +1000,6 @@ drag_data_received  (GtkWidget          *widget,
 	}
 	path_list_free (list);
 
-	gtk_drag_finish (context, TRUE, FALSE, time);
 	quick_lounge_save_order (quick_lounge);
 	dlg_properties_update (quick_lounge->prop_dialog);
 }
@@ -1250,10 +1094,9 @@ get_order_list (QuickLounge *quick_lounge)
 		if (*filename == 0)
 			uri = g_strdup ("");
 		else
-			uri = g_strconcat (quick_lounge->location, 
-					   "/", 
-					   filename, 
-					   NULL);
+			uri = g_build_filename (quick_lounge->location, 
+						filename, 
+						NULL);
 
 		result = g_list_prepend (result, uri);
 	}
@@ -1388,7 +1231,7 @@ quick_lounge_load_uri_sync (QuickLounge  *quick_lounge,
 
 	for (scan = file_list; order_list && scan;) {
 		char *path = scan->data;
-		
+
 		if (path_in_list (order_list, path)) {
 			file_list = g_list_remove_link (file_list, scan);
 			g_list_free (scan);
@@ -1406,10 +1249,9 @@ quick_lounge_load_uri_sync (QuickLounge  *quick_lounge,
 	for (scan = files; scan; scan = scan->next) {
 		char *uri = scan->data;
 
-		if (*uri == 0)  
+		if (*uri == 0) 
 			quick_box_add_separator (quick_box, -1);
-
-		else if (is_desktop_file (uri))
+		else if (is_desktop_file (uri)) 
 			quick_box_add_button (quick_box, uri, -1);
 	}
 
@@ -1436,6 +1278,9 @@ quick_lounge_set_min_visible_cols (QuickLounge *quick_lounge,
 				   int          cols)
 {
 	GError *error = NULL;
+
+	if (cols >= quick_box_get_max_visible_cols (quick_lounge->quick_box))
+		cols = quick_box_get_min_visible_cols (quick_lounge->quick_box);
 	
 	quick_box_set_min_visible_cols (quick_lounge->quick_box, cols);
 	panel_applet_gconf_set_int (PANEL_APPLET (quick_lounge->applet),
@@ -1453,6 +1298,9 @@ quick_lounge_set_max_size (QuickLounge *quick_lounge,
 {
 	GError *error = NULL;
 	
+	if (value <= quick_box_get_min_visible_cols (quick_lounge->quick_box))
+		value = quick_box_get_max_visible_cols (quick_lounge->quick_box);
+
 	quick_box_set_max_visible_cols (quick_lounge->quick_box, value);
 	panel_applet_gconf_set_int (PANEL_APPLET (quick_lounge->applet),
 				    PREFS_MAX_VISIBLE_COLS,
@@ -1486,7 +1334,7 @@ get_unique_dirname (void)
 	char       *base_dir;
 	char       *unique_dir = NULL;
         
-	base_dir = g_strconcat (g_get_home_dir (), "/", BASE_DIR, NULL);
+	base_dir = g_build_filename (g_get_home_dir (), BASE_DIR, NULL);
 	ensure_dir_exists (base_dir, 0700);
 
         while (unique_dir == NULL) {
@@ -1495,10 +1343,7 @@ get_unique_dirname (void)
 		gboolean  exists;
 
 		name = g_strdup_printf ("%d.%d", getpid (), n++);
-		path = g_strconcat (base_dir,
-				    "/",
-				    name,
-				    NULL);
+		path = g_build_filename (base_dir, name, NULL);
 		g_free (name);
 
 		exists = path_is_dir (path);
@@ -1521,9 +1366,9 @@ copy_default_items_to_uri (const char *to_uri)
 {
 	static char * default_items [] = { 
 		/* FIXME : put default items here. */
-		"yelp.desktop",
-		"gnome-terminal.desktop",
 		"nautilus.desktop",
+		"gnome-terminal.desktop",
+		"yelp.desktop",
 		NULL
 	};
 	int i;
@@ -1532,10 +1377,14 @@ copy_default_items_to_uri (const char *to_uri)
 		char *source_uri;
 		char *dest_uri;
 
-		source_uri = g_strconcat ("file://", DATADIR, 
-					  "/applications/", default_items[i],
-					  NULL);
-		dest_uri = g_strconcat (to_uri, "/", default_items[i], NULL); 
+		source_uri = g_build_filename ("file://", 
+					       DATADIR, 
+					       "applications", 
+					       default_items[i],
+					       NULL);
+		dest_uri = g_build_filename (to_uri, 
+					     default_items[i], 
+					     NULL); 
 
 		file_copy (source_uri, dest_uri);
 
@@ -1594,7 +1443,11 @@ quick_lounge_applet_fill (PanelApplet *applet)
 
 	/**/
 
-	panel_applet_add_preferences (applet, "/schemas/apps/quick_lounge_applet/prefs", NULL);
+	panel_applet_add_preferences (applet, "/schemas/apps/quick-lounge-applet/prefs", &error);
+	if (error != NULL) {
+		g_print (error->message);
+		g_clear_error (&error);
+	}
 
 	min_cols = panel_applet_gconf_get_int (applet, PREFS_MIN_VISIBLE_COLS, &error);
 	if ((error != NULL) || (min_cols < 0)) {
@@ -1670,8 +1523,6 @@ quick_lounge_applet_fill (PanelApplet *applet)
 
 	/**/
 
-	gtk_widget_show (GTK_WIDGET (quick_lounge->quick_box));
-
 	gtk_container_add (GTK_CONTAINER (applet), GTK_WIDGET (quick_lounge->quick_box));
 
 	panel_applet_set_flags (applet,
@@ -1679,8 +1530,6 @@ quick_lounge_applet_fill (PanelApplet *applet)
 				PANEL_APPLET_EXPAND_MINOR |
 				PANEL_APPLET_HAS_HANDLE);
 
-	gtk_widget_show (GTK_WIDGET (applet));
-
 	g_signal_connect (G_OBJECT (applet),
 			  "destroy",
                           G_CALLBACK (applet_destroy),
@@ -1705,6 +1554,11 @@ quick_lounge_applet_fill (PanelApplet *applet)
                           G_CALLBACK (applet_size_request),
                           quick_lounge);
 
+	g_signal_connect (G_OBJECT (applet), 
+			  "size_allocate",
+                          G_CALLBACK (applet_size_allocate),
+                          quick_lounge);
+
 	panel_applet_setup_menu_from_file (applet,
 					   NULL,
 					   APPLET_UI,
@@ -1715,6 +1569,9 @@ quick_lounge_applet_fill (PanelApplet *applet)
 	quick_lounge_load_uri (quick_lounge, uri);
 	g_free (uri);
 
+	gtk_widget_show (GTK_WIDGET (quick_lounge->quick_box));
+	gtk_widget_show (GTK_WIDGET (applet));
+
 	return TRUE;
 }
 
@@ -1731,8 +1588,9 @@ quick_lounge_factory (PanelApplet *applet,
 }
 
 
-PANEL_APPLET_BONOBO_SHLIB_FACTORY (APPLET_FACTORY_IID,
-				   PANEL_TYPE_APPLET,
-				   "Quick Lounge Applet",
-				   quick_lounge_factory, 
-				   NULL);
+PANEL_APPLET_BONOBO_FACTORY (APPLET_FACTORY_IID,
+			     PANEL_TYPE_APPLET,
+			     "quick-lounge-applet",
+			     "0",
+			     quick_lounge_factory, 
+			     NULL)
